export function demoAttributes(ogma) {
  // Assign attributes

  let node0 = ogma.addNode({ id: 0 });

  node0.setAttributes({
    x: 10,
    y: 30,
    color: 'blue',
    text: { content: 'My node' }
  });

  console.log(node0.getAttribute('color')); // "blue"

  // Original attributes

  ogma.addNode({
    id: 1,
    attributes: {
      x: 30,
      y: 30,
      color: 'red',
      text: { content: 'My other node' }
    }
  });

  // Reset attributes

  let node2 = ogma.addNode({
    id: 2,
    attributes: {
      x: 20,
      y: 50,
      color: 'green',
      text: { content: 'Yet another node' }
    }
  });

  node2.setAttributes({ color: 'darkblue', shape: 'square' });

  console.log(node2.getAttribute('color')); // "red"
  console.log(node2.getAttribute('shape')); // "square"

  node2.resetAttributes();

  console.log(node2.getAttribute('color')); // "green"
  console.log(node2.getAttribute('shape')); // "circle"

  // `setAttributes` on a list

  ogma.getNodes().setAttributes({ color: 'gold' });

  // `setAttributes` with spreading

  ogma.getNodes([0, 1]).setAttributes([
    { x: 0, y: 40, radius: 3, color: 'lightgreen' },
    { x: 5, y: 55, radius: 2, color: 'pink' }
  ]);

  console.log(ogma.getNode(0).getAttribute('color')); // "lightgreen"
  console.log(ogma.getNode(1).getAttribute('color')); // "pink"

  // `getAttribute(s)` on a list

  let nodes = ogma.getNodes([0, 1]);

  console.log(nodes.getAttributes(['x', 'y'])); // [{x: 0, y: 40}, {x: 5, y: 55}]
  console.log(nodes.getAttribute('color')); // ['lightgreen', 'pink']

  ogma.view.locateGraph();
}
